Scripting API
=============

ScriptContext
-------------

.. autoclass:: telix.scripts.ScriptContext
   :members:

Room
----

.. autoclass:: telix.rooms.Room
   :members:

RoomStore
---------

.. autoclass:: telix.rooms.RoomStore
   :members: rooms, get_room, has_room, find_path, search, find_same_name,
             get_home_for_area, blocked_rooms, room_nums,
             toggle_bookmark, toggle_blocked, toggle_home, toggle_marked
